import axios from 'axios'

// Select Movie
export const SELECT_MOVIE = 'SELECT_MOVIE'
export function selectMovie(index) {
  return {
    type: SELECT_MOVIE,
    index
  }
}

export const IS_USER_LOGGED_IN = 'IS_USER_LOGGED_IN'
export function isUserLoggedIn() {
  return {
    type: IS_USER_LOGGED_IN,
  }
}

export const ADD_ERROR = 'ADD_ERROR'
export function addError(message) {
  return {
    type: ADD_ERROR,
    payload: {
      message,
    }
  }
}

export const DISMISS_ERROR = 'DISMISS_ERROR'
export function dismissError() {
  return {
    type: DISMISS_ERROR,
  }
}

export const USER_LOGOUT = 'USER_LOGOUT'
export function userLogout() {
  return {
    type: USER_LOGOUT,
  }
}

export const USER_LOGIN_FULFILLED = 'USER_LOGIN_FULFILLED',
             USER_LOGIN_PENDING = 'USER_LOGIN_PENDING';
export function loginUser(username, password) {
  return function(dispatch) {
    dispatch({
      type: USER_LOGIN_PENDING,
    })
    axios.post(
      '/users/login',
      {
        username: username,
        password: password,
      },
    ).then(response => {
      if (response.data && response.data.type && response.data.type === 'error')
      {
        dispatch({
          type: ADD_ERROR,
          payload: {
            message: response.data.message,
          }
        })
      }
      dispatch({
        type: USER_LOGIN_FULFILLED,
        payload: response,
      })
    }).catch(error => {
      console.log(error)
    })
  }
}

export const MOVIE_LIST_FETCH_FULFILLED = 'MOVIE_LIST_FETCH_FULFILLED',
             MOVIE_LIST_FETCH_PENDING = 'MOVIE_LIST_FETCH_PENDING';
export function fetchMovies() {
  const token = localStorage.getItem('token');
  const header = 'Bearer ' + token;
  return function(dispatch) {
    dispatch({
      type: MOVIE_LIST_FETCH_PENDING,
    })
    axios.get('/movies/explore/popular', {
      headers: { 'Authorization': header },
    })
    .then(response => {
      if (response.data.type && response.data.type === 'error')
      {
        dispatch({
          type: ADD_ERROR,
          payload: {
            message: response.data.message,
          }
        })
      }
      dispatch({
        type: MOVIE_LIST_FETCH_FULFILLED,
        payload: response,
      })
    })
    .catch(error => {
      // Unauthorized
      if (error.response.status == 401) {
        dispatch({
          type: USER_LOGOUT,
        })
      }
      dispatch({
        type: ADD_ERROR,
        payload: {
          message: error.response.data,
        }
      })
    })
  }
}
